@@ -89,7 +89,7 @@ def test_BlueprintInput():
     test_time = np.array([0, 1, 1, 2, 3, 5, 8, 13])
     test_trigger = np.array([0, 1, 0, 0, 0, 0, 0, 0])
     test_chocolate = np.array([1, 0, 0, 1, 0, 0, 1, 0])
-    test_timeseries = [test_time.copy(), test_trigger, test_chocolate]
+    test_timeseries = [test_time, test_trigger, test_chocolate]
     test_freq = [42.0, 3.14, 20.0]
     test_chn_name = ['time', 'trigger', 'chocolate']
     test_units = ['s', 's', 'sweetness']
@@ -101,11 +101,12 @@ def test_BlueprintInput():
 
     # Tests rename_channels
     new_names = ['trigger', 'time', 'lindt']
-    blueprint_in.rename_channels(new_names.copy())
+    blueprint_in.rename_channels(new_names)
     assert blueprint_in.ch_name == ['time', 'trigger', 'lindt']
 
     # Tests return_index
     test_index = blueprint_in.return_index(1)
+    assert test_index[0] is not test_trigger
     assert (test_index[0] == test_trigger).all()
     assert test_index[1] == len(test_timeseries)
     assert test_index[2] == test_freq[1]
@@ -140,7 +141,7 @@ def test_cta_time_interp():
     """Test BlueprintInput.check_trigger_amount with time resampling."""
     test_time = np.array([0, 7])
     test_trigger = np.array([0, 1, 0, 0, 0, 0, 0, 0])
-    test_timeseries = [test_time.copy(), test_trigger]
+    test_timeseries = [test_time, test_trigger]
     test_freq = [42.0, 3.14]
     test_chn_name = ['time', 'trigger']
     test_units = ['s', 's']
